==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_fields/TASKDYNAMICCHECKLISTCONDITIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for TASKDYNAMICCHECKLISTCONDITIONID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="TASKDYNAMICCHECKLISTCONDITIONID_Type">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TASKLISTID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TASKDYNAMICCHECKLISTCONDITIONCODE" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TASKDYNAMICCHECKLISTCONDITIONID_Type", propOrder = {
    "tasklistid",
    "taskdynamicchecklistconditioncode"
})
public class TASKDYNAMICCHECKLISTCONDITIONID_Type {

    @XmlElement(name = "TASKLISTID", required = true)
    protected TASKLISTID_Type tasklistid;
    @XmlElement(name = "TASKDYNAMICCHECKLISTCONDITIONCODE")
    protected String taskdynamicchecklistconditioncode;

    /**
     * Gets the value of the tasklistid property.
     * 
     * @return
     *     possible object is
     *     {@link TASKLISTID_Type }
     *     
     */
    public TASKLISTID_Type getTASKLISTID() {
        return tasklistid;
    }

    /**
     * Sets the value of the tasklistid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TASKLISTID_Type }
     *     
     */
    public void setTASKLISTID(TASKLISTID_Type value) {
        this.tasklistid = value;
    }

    /**
     * Gets the value of the taskdynamicchecklistconditioncode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTASKDYNAMICCHECKLISTCONDITIONCODE() {
        return taskdynamicchecklistconditioncode;
    }

    /**
     * Sets the value of the taskdynamicchecklistconditioncode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTASKDYNAMICCHECKLISTCONDITIONCODE(String value) {
        this.taskdynamicchecklistconditioncode = value;
    }

}

==> eam-wshub-proxyclient-12.1-4-sources.jar: net/datastream/schemas/mp_fields/TASKDYNAMICCHECKLISTCONDITIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for TASKDYNAMICCHECKLISTCONDITIONID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="TASKDYNAMICCHECKLISTCONDITIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TASKLISTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TASKDYNAMICCHECKLISTCONDITIONCODE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TASKDYNAMICCHECKLISTCONDITIONID_Type", propOrder = {
    "tasklistid",
    "taskdynamicchecklistconditioncode"
})
public class TASKDYNAMICCHECKLISTCONDITIONID_Type {

    @XmlElement(name = "TASKLISTID", required = true)
    protected TASKLISTID_Type tasklistid;
    @XmlElement(name = "TASKDYNAMICCHECKLISTCONDITIONCODE")
    protected String taskdynamicchecklistconditioncode;

    /**
     * Gets the value of the tasklistid property.
     * 
     * @return
     *     possible object is
     *     {@link TASKLISTID_Type }
     *     
     */
    public TASKLISTID_Type getTASKLISTID() {
        return tasklistid;
    }

    /**
     * Sets the value of the tasklistid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TASKLISTID_Type }
     *     
     */
    public void setTASKLISTID(TASKLISTID_Type value) {
        this.tasklistid = value;
    }

    /**
     * Gets the value of the taskdynamicchecklistconditioncode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTASKDYNAMICCHECKLISTCONDITIONCODE() {
        return taskdynamicchecklistconditioncode;
    }

    /**
     * Sets the value of the taskdynamicchecklistconditioncode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTASKDYNAMICCHECKLISTCONDITIONCODE(String value) {
        this.taskdynamicchecklistconditioncode = value;
    }

}
